@@ -12,7 +12,7 @@ has raw => ( is => 'ro', isa => ScalarRef );
 has is_success  => ( is => 'lazy', isa => Bool, init_arg => undef );
 has is_verisign => ( is => 'lazy', isa => Bool, init_arg => undef );    # true, if invalid request to the verisign server
 has md5         => ( is => 'lazy', isa => Str,  init_arg => undef );
-has is_found    => ( is => 'lazy', isa => Bool, init_arg => undef );    # whois response is valid, and domain was found (nto available for registration)
+has is_found    => ( is => 'lazy', isa => Bool, init_arg => undef );    # whois response is valid, and domain was found on whois server (not available for registration)
 
 no Pcore;
 
